#' `teal`: Interactive exploration of clinical trials data
#'
#' The `teal` package provides a `shiny` based framework for creating an
#' interactive data analysis environment.
#'
#' To learn mode about the package, visit the [project website](https://insightsengineering.github.io/teal/latest-tag/)
#' or read the [init()] manual page.
#'
#' @keywords internal
"_PACKAGE"

#' @import shiny teal.data teal.slice
#' @importFrom stats setNames
#' @export
NULL
